--[[
Baggins_AltLevel

Author: ZorbaTHut (Ben Wilhelm) <zorba-baggins-altlevel@pavlovain.net>

Thanks to Nargiddley for writing Baggins

License

Copyright (c) 2008 Ben Wilhelm

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

Baggins_AltLevel = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0","AceEvent-2.0")

local Baggins_AltLevel = Baggins_AltLevel

local dewdrop = AceLibrary:HasInstance("Dewdrop-2.0") and AceLibrary("Dewdrop-2.0")
local L = AceLibrary("AceLocale-2.2"):new("Baggins_AltLevel")

Baggins_AltLevels = {}
local Baggins_AltLevel_TheseCharacters = nil

L:RegisterTranslations("enUs", function()
	return {
		["AltLevel"] = true,
    ["Filter by the levels of your alts"] = true,
    ["From relative level:"] = true,
    ["To relative level:"] = true,
	};
end)

-- Feel free to fix any of the localizations without asking first and check them into the SVN.
L:RegisterTranslations("esES", function()
	return {
		--["AltLevel"] = true,
	};
end)

L:RegisterTranslations("deDE", function()
	return {

	};
end)

L:RegisterTranslations("frFR", function()
	return {

	};
end)

L:RegisterTranslations("koKR", function()
	return {

	};
end)

L:RegisterTranslations("znCN", function()
	return {

	};
end)

L:RegisterTranslations("znTW", function()
	return {

	};
end)

local function Matches(bag,slot,rule)
  link = GetContainerItemLink(bag, slot)
  if not link then return false end
  
  local _,_,_, itemLevel, itemMinLevel = GetItemInfo(link)

  if Baggins_AltLevel_TheseCharacters[rule.alt_name] then
    local charlevel = Baggins_AltLevel_TheseCharacters[rule.alt_name].level
    return itemMinLevel >= (charlevel + rule.minlevel) and itemMinLevel <= (charlevel + rule.maxlevel)
  end
  
  return false  -- we don't know about that character
end

local function GetName(rule)
  return string.format("AltLevel of %s (%d..%d)", rule.alt_name, rule.minlevel, rule.maxlevel)
end

local function CleanRule(rule)
	rule.alt_name = ""
	rule.minlevel = -5
  rule.maxlevel = 2
end

local function DewDropOptions(rule, level, value)
	if level == 1 then
		dewdrop:AddLine("text", L["AltLevel"], "isTitle", true)
    
    for name, _ in pairs(Baggins_AltLevel_TheseCharacters) do
      dewdrop:AddLine('text', name, "checked", rule.alt_name == name, "func", function(b) rule.alt_name = name; Baggins:OnRuleChanged() end);
    end
    
    dewdrop:AddLine('text', L["From relative level:"], "hasArrow", true, "hasEditBox", true, "editBoxText", tonumber(rule.minlevel) or -5, "editBoxFunc", function(text) rule.minlevel = tonumber(text) or -5; Baggins:OnRuleChanged() end);
    dewdrop:AddLine('text', L["To relative level:"], "hasArrow", true, "hasEditBox", true, "editBoxText", tonumber(rule.maxlevel) or 2, "editBoxFunc", function(text) rule.maxlevel = tonumber(text) or 2; Baggins:OnRuleChanged() end);
  end
end

function Baggins_AltLevel:OnLevel(newlevel)
  Baggins_AltLevel_TheseCharacters[UnitName("player")].level = newlevel
end

function Baggins_AltLevel:OnInitialize()
  local realm = GetRealmName()
  local faction = UnitFactionGroup("player")
  local name = UnitName("player")

  if not Baggins_AltLevels[realm] then Baggins_AltLevels[GetRealmName()] = {} end
  if not Baggins_AltLevels[realm][faction] then Baggins_AltLevels[realm][faction] = {} end
  Baggins_AltLevel_TheseCharacters = Baggins_AltLevels[realm][faction]
  
  if not Baggins_AltLevel_TheseCharacters[name] then Baggins_AltLevel_TheseCharacters[name] = {} end
  Baggins_AltLevel_TheseCharacters[name].level = UnitLevel("player")
  
  self:RegisterEvent("PLAYER_LEVEL_UP", "OnLevel") 
  
	Baggins:AddCustomRule("AltLevel", {
		DisplayName = L["AltLevel"],
		Description = L["Filter by the levels of your alts"],
		Matches = Matches,
		GetName = GetName,
		CleanRule = CleanRule,
		DewDropOptions = DewDropOptions
	})
  Baggins:ForceFullUpdate()
  
  DEFAULT_CHAT_FRAME:AddMessage("AL Initialized")
  DEFAULT_CHAT_FRAME:AddMessage("AL Initialized")
  DEFAULT_CHAT_FRAME:AddMessage("AL Initialized")
end


DEFAULT_CHAT_FRAME:AddMessage("AL ministarted")